SELECT RECIPIENTS.ORG_ID||'|'||RECIPIENTS.RECIPIENT_ID  AS "EXTERNAL_KEY",
       RECIPIENTS.TARGET_NAME                           AS "GROUP_NAME",
       GRP.DESCRION                                     AS "DESCRIPTION",
       GRP.STATUS                                       AS "STATUS",
       GRP.USE_EMERG_DVC                                AS "USE_DEFAULT_DEVICES",
       (SELECT TZ.ID
          FROM ORG_TZ, TZ
         WHERE ORG_TZ.ORG_TZ_ID = GRP.ORG_TZ_ID
           AND TZ.TZ_ID = ORG_TZ.TZ_ID)
                                                        AS "TIMEZONE",
       (SELECT SITES.NAME
          FROM SITES
         WHERE SITES.SITE_ID = GRP.SITE_ID)
                                                        AS "GROUP_SITE_NAME",
       COALESCE(y.valid_sup, z.default_sup)             AS "SUPERVISOR_LIST",


       'Y'                                              AS "OBSERVED_BY_ALL",
       ''                                               AS "OBSERVER_LIST",
       GRP.DUPLICATED                                   AS "ALLOW_DUPLICATES",
       'Y'                                              AS "IS_EXTERNALLY_OWNED",
       'Y'                                              AS "ALARMPOINT_ACTION",
       NULL                                             AS "LAST_SYNC_DATE"
FROM GRP
INNER JOIN RECIPIENTS ON RECIPIENTS.RECIPIENT_ID = GRP.GRP_ID
  AND (RECIPIENTS.DELETED_ID = -1 or RECIPIENTS.DELETED_ID is null)

LEFT JOIN (
    SELECT gs.grp_id, STRING_AGG(r.ORG_ID||'|'||r.RECIPIENT_ID) as valid_sup
      FROM GRP_SUPS gs INNER JOIN RECIPIENTS r ON  gs.person_id = r.recipient_id
     WHERE
          NOT EXISTS (
            SELECT *
            FROM PERSONS_FUNC, ROLE
            WHERE ROLE.ROLE_ID = PERSONS_FUNC.FUNC_ID
                AND PERSONS_FUNC.PERSON_ID = r.RECIPIENT_ID
                AND ROLE.NAME IN ('Super Admin', 'Company Admin')
          )
     GROUP BY gs.grp_id
) y ON GRP.grp_id = y.grp_id

LEFT JOIN (
    SELECT r2.org_id, r2.ORG_ID||'|'||r2.RECIPIENT_ID AS default_sup
      FROM
          RECIPIENTS r2
      WHERE
          LOWER(r2.target_name) = LOWER('%%_DEFAULT_SUPERVISOR_TARGET_NAME_%%')
          AND 1 = %%_ALLOW_DEFAULT_SUPERVISOR_%%
          and r2.deleted_id = -1
          AND NOT EXISTS (
            SELECT *
            FROM PERSONS_FUNC, ROLE
            WHERE ROLE.ROLE_ID = PERSONS_FUNC.FUNC_ID
                AND PERSONS_FUNC.PERSON_ID = r2.RECIPIENT_ID
                AND ROLE.NAME IN ('Super Admin', 'Company Admin')
          )
          AND EXISTS (SELECT *
            FROM PERSONS_FUNC, ROLE
            WHERE ROLE.ROLE_ID = PERSONS_FUNC.FUNC_ID
                AND PERSONS_FUNC.PERSON_ID = r2.RECIPIENT_ID
                AND ROLE.NAME = 'Group Supervisor')
) z ON z.ORG_ID = RECIPIENTS.ORG_ID

WHERE (GRP.DELETED_ID = -1 or GRP.DELETED_ID is null)
   -- REPLACE_WITH_ORG_FILTER
ORDER by RECIPIENTS.WHEN_UPDATED, GRP.WHEN_UPDATED
