SELECT
  INNER_EXTERNAL_KEY        AS "EXTERNAL_KEY",
  INNER_GROUP_KEY           AS "GROUP_KEY",
  SUB_TARGET_NAME           AS "SUB_TARGET_NAME",
  DESCRIPTION               AS "DESCRIPTION",
  USE_DEFAULT_DEVICES       AS "USE_DEFAULT_DEVICES",
  Case 
    WHEN LENGTH(MAX(Escalation_Schedule)) > 100 THEN
         SUBSTR(MAX(ESCALATION_SCHEDULE), 1, Instr(SUBSTR(MAX(ESCALATION_SCHEDULE),1,100), ',', -1, 1)-1)
    ELSE MAX(ESCALATION_SCHEDULE)
  END AS "ESCALATION_SCHEDULE",
  IS_ROUND_ROBIN            AS "IS_ROUND_ROBIN",
  ADD_24X7_COVERAGE         AS "ADD_24X7_COVERAGE",
  IEO                       AS "IS_EXTERNALLY_OWNED",
  ALARMPOINT_ACTION         AS "ALARMPOINT_ACTION",
  LAST_SYNC_DATE            AS "LAST_SYNC_DATE"
FROM
(
SELECT RECIPIENTS.ORG_ID||'|'||RECIPIENTS.RECIPIENT_ID
                                                          AS "INNER_EXTERNAL_KEY",
       grp_r.ORG_ID||'|'||GRP.GRP_ID                      AS "INNER_GROUP_KEY",
       RECIPIENTS.SUB_TARGET_NAME                         AS "SUB_TARGET_NAME",
       TM.DESCRION                                        AS "DESCRIPTION",
       TM.USE_EMERG_DVC                                   AS "USE_DEFAULT_DEVICES",
       CASE
         WHEN ESCALATION IS NULL THEN '0'
         ELSE STRING_AGG(ESCALATION) OVER(PARTITION By TM.TM_ID ORDER BY ESC_SEQ_NUM)
       END
                                                          AS "ESCALATION_SCHEDULE",
       CASE
         WHEN TM.TM_TYPE = 'BASIC' OR TM.TM_TYPE = 'TIME_BASED_ROUND_ROBIN' THEN 'N'
         ELSE 'Y'
       END                                                AS "IS_ROUND_ROBIN",
       'N'                                                AS "ADD_24X7_COVERAGE",
       'Y'                                                AS "IEO",
       'Y'                                                AS "ALARMPOINT_ACTION",
       TO_DATE('')                                        AS "LAST_SYNC_DATE"
FROM TM LEFT OUTER JOIN TM_ESCALATION esc
         ON TM.TM_ID = esc.tm_id,
       RECIPIENTS, GRP, RECIPIENTS grp_r
WHERE RECIPIENTS.RECIPIENT_ID = TM.TM_ID
   AND GRP.GRP_ID = TM.GRP_ID
   AND grp_r.RECIPIENT_ID = GRP.GRP_ID
   AND (TM.DELETED_ID = -1 or TM.DELETED_ID is null)
   AND (GRP.DELETED_ID = -1 or GRP.DELETED_ID is null)
   AND (RECIPIENTS.DELETED_ID = -1 or RECIPIENTS.DELETED_ID is null)
   -- REPLACE_WITH_ORG_FILTER
ORDER BY RECIPIENTS.WHEN_UPDATED, TM.WHEN_UPDATED
)
GROUP BY INNER_EXTERNAL_KEY, INNER_GROUP_KEY, SUB_TARGET_NAME, DESCRIPTION, USE_DEFAULT_DEVICES, IS_ROUND_ROBIN,
         ADD_24X7_COVERAGE, IEO, ALARMPOINT_ACTION, LAST_SYNC_DATE